@@ -313,9 +313,7 @@ void delete_allalarm_events()
 {
     time_t start_time = 0;
     time_t end_time = 0;
-    int32_t result = 0;
     cookie_t *events = 0;
-    cookie_t cookie = 0;
 
     events = alarmd_event_query(start_time, end_time, 0,0,"osso_rss_feed_reader");
     if (events == NULL) {
@@ -365,12 +363,9 @@ static guint _setup_iphb_callback(gpointer data)
 	Iphb_cb_data *iphb_data = (Iphb_cb_data *)data;
 	GSourceFunc funcPtr = (GSourceFunc)(iphb_data->iphb_callback);
 	GConfClient* gconf = gconf_client_get_default();
-	iphb_t iphb_handle = NULL;
 	gint mintime = 0, maxtime = 0;
 	time_t new_time = 0;
 
-	int iphb_fd = gconf_client_get_int(gconf, RSS_SETTINGS_IPHB_HANDLE_ID, NULL);
-
 	gboolean autoupdate = gconf_client_get_bool(gconf,
 			RSS_SETTINGS_AUTOMATIC_UPDATES, NULL);
 
@@ -402,8 +397,9 @@ static guint _setup_iphb_callback(gpointer data)
 
 		//if( 30 >= (upd_interval-30) )
 		//	upd_interval = 30;
-
+		if (iphb_data->source_id) {
 		remove_iphb_callback(iphb_data->source_id);
+		}
 		iphb_data->source_id = 0;
 		//iphb_data->source_id = g_timeout_add((guint)(1000 * (upd_interval-30)), (GSourceFunc)(funcPtr), NULL);
 		iphb_data->source_id = g_timeout_add((guint)(1000 * mintime), (GSourceFunc)(funcPtr), NULL);
@@ -421,34 +417,26 @@ guint setup_iphb_callback(Iphb_cb_data *data)
 gboolean _setup_alarm_event(gboolean replace, gboolean now, Iphb_cb_data *data)
 {
 	DMSG("Entering %s %d %d\n",__FUNCTION__,replace,now);
-	GConfClient* gconf = gconf_client_get_default();
 
-	gboolean iphb_handle = gconf_client_get_bool(gconf, RSS_SETTINGS_ALARM_ID, NULL);
-	config_check_first_time(gconf);
-	iphb_handle = gconf_client_get_bool(gconf, RSS_SETTINGS_ALARM_ID, NULL);
 	Iphb_cb_data *iphb_data = (Iphb_cb_data *)data;
 	refreshnow = now;
 
 	if (!replace) {
 		/* check if we have a poll setup for iphb */
 		/* Check FD_SET -> FD_ISSET() */
-		if(FALSE != iphb_handle) {
 			//g_object_unref(gconf);
+			if(FALSE != data->iphb_handle) {
 			return TRUE;
 		}
 	}
+	if (data->iphb_handle) {
+		 if(iphb_data->source_id > 0) {
+		g_source_remove(iphb_data->source_id);
+		iphb_data->source_id = 0;
+	    }
 
-	if (FALSE == iphb_handle)
-	{
-		g_timeout_add(100, _setup_alarm_timeout, (gpointer)(data));
-	} else {
-
-		if(iphb_data->source_id > 0) {
-			g_source_remove(iphb_data->source_id);
-			iphb_data->source_id = 0;
-		}
-		g_timeout_add(100, _setup_alarm_timeout, (gpointer)(data));
 	}
+	g_timeout_add(100, _setup_alarm_timeout, (gpointer)(data));
 
 	//g_object_unref(gconf);
 	return TRUE;
@@ -459,30 +447,23 @@ gboolean _setup_alarm_timeout(gpointer data)
 {
 
 	GConfClient* gconf = gconf_client_get_default();
-	gboolean iphb_configured = FALSE;
+
 
 	gboolean autoupdate = gconf_client_get_bool(gconf, 
 			RSS_SETTINGS_AUTOMATIC_UPDATES, NULL);
-	iphb_t iphb_handle = NULL;
-	int iphb_fd = 0;
+	gboolean iphb_configured = FALSE;
 	gboolean iphb_handle_created = gconf_client_get_bool(gconf, RSS_SETTINGS_ALARM_ID, NULL);
 	Iphb_cb_data *iphb_data = (Iphb_cb_data *)data;
 	gint mintime = 0, maxtime = 0;
 	time_t new_time = 0;
 
-	if(FALSE == iphb_handle_created) {
-		iphb_handle = create_iphb_handle();
-		iphb_data->iphb_handle = iphb_handle;
+	if (iphb_data->iphb_handle == NULL && (iphb_handle_created == FALSE)) {
+		iphb_data->iphb_handle = create_iphb_handle();
+		iphb_configured = TRUE;
+		gconf_client_set_bool(gconf, RSS_SETTINGS_ALARM_ID, iphb_configured, NULL);
+
 	}
 
-	if(FALSE == iphb_handle_created) {
-		iphb_fd = get_iphb_fd(iphb_handle);
-	}
-	else {
-		iphb_fd = gconf_client_get_int(gconf, RSS_SETTINGS_IPHB_HANDLE_ID, NULL);
-	}
-
-	gconf_client_set_int(gconf, RSS_SETTINGS_IPHB_HANDLE_ID, iphb_fd, NULL);
 	
 	if (autoupdate)
 	{
@@ -516,12 +497,8 @@ gboolean _setup_alarm_timeout(gpointer data)
 		
 		//iphb_timeout = iphb_wait(iphb_handle, (guint)((upd_interval*60 - 30)), (guint)((upd_interval*60)), 0);
 		//iphb_timeout = iphb_wait(iphb_handle, (guint)((upd_interval - 30)), (guint)((upd_interval)), 0);
-		iphb_timeout = iphb_wait(iphb_handle, (guint)(mintime), (guint)(maxtime), 0);
+		iphb_timeout = iphb_wait(iphb_data->iphb_handle, (guint)(mintime), (guint)(maxtime), 0);
 
-		if(FALSE == iphb_handle_created) {
-			iphb_configured = TRUE;
-			gconf_client_set_bool(gconf, RSS_SETTINGS_ALARM_ID, iphb_configured, NULL);
-		}
 	}
 
 //	g_object_unref(gconf);
@@ -540,32 +517,20 @@ gboolean setup_alarm_event_now(gboolean replace, Iphb_cb_data *data)
 	return _setup_alarm_event(replace, TRUE, data);
 }
 
-iphb_t close_iphb_handle(Iphb_cb_data data)
+iphb_t close_iphb_handle(Iphb_cb_data *data)
 {
-        GConfClient* gconf = gconf_client_get_default();
-	gboolean iphb_configured = FALSE;
-	iphb_configured = gconf_client_get_bool(gconf, RSS_SETTINGS_ALARM_ID, NULL);
-	if(TRUE == iphb_configured) {
-		iphb_configured = FALSE;
-		int iphb_fd = 0;
-		/*iphbt_t is nothing but a (void*) */
-		iphb_t return_val = 0 ;
-		
+        iphb_t return_val = 0 ;
+	gboolean iphb_configured = FALSE;	
+	GConfClient* gconf = gconf_client_get_default();
 
-		gconf_client_set_bool(gconf, RSS_SETTINGS_ALARM_ID, iphb_configured, NULL);
-		gconf_client_set_int(gconf, RSS_SETTINGS_IPHB_HANDLE_ID, iphb_fd, NULL);
-
-		/*defense added to prevent double free of iphb_handle */
-		DMSG(" About to free iphb handler  %d\n", data.iphb_handle);
-		if (data.iphb_handle != NULL ) {
-			/* iphbh handle will be freed inside */
-			DMSG(" freeing iphb handler \n");
-			return_val = iphb_close(data.iphb_handle);
-			data.iphb_handle = NULL;
-		}
-       		return return_val;		
+	if (data->iphb_handle != NULL ) {
+	    return_val = iphb_close(data->iphb_handle);
+	    data->iphb_handle = NULL;		
 	}
-	return NULL;
+	iphb_configured = FALSE;
+	gconf_client_set_bool(gconf, RSS_SETTINGS_ALARM_ID, iphb_configured, NULL);
+	return return_val;	
+
 }
 
 gboolean remove_iphb_callback(guint source_id)
@@ -602,9 +567,6 @@ void conf_reset_default_values(GConfClient* conf)
     gconf_client_set_bool(conf, LAST_WINDOW_MAXIMIZED, FALSE, NULL);
     gconf_client_set_bool(conf, LAST_SHOWFOLDERS, TRUE, NULL);
 
-//    gconf_client_set_bool(conf, RSS_SETTINGS_ALARM_ID, FALSE, NULL);	// Rama Added
-//    gconf_client_set_int(conf, RSS_SETTINGS_IPHB_HANDLE_ID, 0, NULL);	// Rama Added
-
     gconf_client_set_string(conf, START_FIRST_TIME, COMPILE_TIME, NULL);
 
     gconf_client_add_dir(conf, RSS_SETTINGS, GCONF_CLIENT_PRELOAD_NONE, NULL);
